/**
 * Componente de card para a seleção dos apps
 *
 * @author               Felipe Hamester, João Leão e Arthur Henz
 * @param image          Imagem do app
 * @param name           Nome do app
 *
 * @example
 *
 *                       Use example
 *                       <AppButtonComponent
 *                       name="Whatsapp"
 *                       image={require('../../assets/whatsapp-logo.png')}
 *                       ></AppButtonComponent>
 *
 *
 *
 */

import React from 'react';
import {
  StyleSheet,
  TouchableOpacity,
  Text,
  Image,
  Platform,
  Dimensions,
} from 'react-native';
import colors from '../constants/colors';

export default function AppButtonComponent({ name, image, action }) {
  return (
    <TouchableOpacity style={styles.card} onPress={action}>
      <Image style={styles.cardImage} source={image} />
      <Text style={styles.appName}>{name}</Text>
    </TouchableOpacity>
  );
}

const width = Dimensions.get('screen').width - 40;
const cardSize = width * 0.3;

const styles = StyleSheet.create({
  card: {
    marginVertical: 10,
    backgroundColor: colors.background,
    borderRadius: 15,
    width: cardSize,
    height: cardSize,
    margin: 5,
    alignItems: 'center',
    justifyContent: 'center',
    elevation: 6,
    borderWidth: 1,
    borderColor: colors.transparent,
    ...Platform.select({
      ios: {
        shadowColor: colors.text,
        shadowOpacity: 0.25,
        shadowOffset: { width: 0, height: 1 },
        shadowRadius: 4,
      },
    }),
  },
  cardImage: {
    width: '50%',
    height: '50%',
  },
  appName: {
    fontSize: 18,
    color: colors.text,
    textAlign: 'center',
  },
});
