/**
 * Componente de modelo que cria uma barra de buscas
 *
 * @author              Marlon Saldanha, Pablo Alles
 * @param sendSearch    callback chamado quando o conteúdo da search bar é alterado
 * @example             <SearchBarComponent
 *                      />
 */

import React from 'react';
import { StyleSheet, View, TextInput } from 'react-native';
import FeatherIcon from 'react-native-vector-icons/Feather';

export default function SearchBarComponent({
  handleEnter,
  handleChange,
  placeholder = 'Buscar',
}) {
  return (
    <View style={styles.bar}>
      <FeatherIcon name="search" size={24} color="white" style={styles.icon} />
      <TextInput
        placeholder={placeholder}
        placeholderTextColor="white"
        style={styles.input}
        onSubmitEditing={handleEnter}
        onChangeText={text => handleChange(text)}
      />
    </View>
  );
}

const styles = StyleSheet.create({
  bar: {
    flexDirection: 'row',
    backgroundColor: 'rgba(255, 255, 255, 0.3)',
    height: 38,
    alignItems: 'center',
    borderRadius: 50,
    paddingLeft: 54,
    position: 'relative',
  },
  input: {
    fontSize: 18,
    color: 'white',
    fontWeight: '500',
    width: '100%',
    paddingRight: 20,
  },
  icon: {
    left: 15,
    position: 'absolute',
  },
});
