/**
 * Tela Seleção de Aplicativos Instalados
 *
 * @author            Eduardo Cardoso
 * @example           <AppSelectionScreen/>
 */

import React, { useState } from 'react';
import { StyleSheet, View, Text, Alert } from 'react-native';
import colors from '../constants/colors';
import { CommonActions } from '@react-navigation/native';

import HeaderComponent from '../components/HeaderComponent';
import BodyComponent from '../components/BodyComponent';
import FooterComponent from '../components/FooterComponent';
import ButtonComponent from '../components/ButtonComponent';
import CardComponent from '../components/CardComponent';
import APPS from '../constants/apps';
import { updateInstalledApps } from '../api';

export default function SignupAppSelectionScreen({ navigation }) {
  const [appsInstalled, setAppInstalled] = useState([]);

  async function send() {
    try {
      const response = await updateInstalledApps(appsInstalled);
      console.log(response.data);
    } catch (error) {
      console.warn(error);
    }
    navigation.dispatch(
      CommonActions.reset({
        index: 0,
        routes: [{ name: 'Root' }],
      }),
    );
  }

  function checkAlreadyAppsInstalled(id) {
    return appsInstalled.includes(id);
  }

  function cardOnChange(selected, id) {
    !selected ? addApp(id) : removeApp(id);
  }

  function removeApp(id) {
    setAppInstalled(appsInstalled.filter(value => value !== id));
  }

  function addApp(id) {
    setAppInstalled([...appsInstalled, id]);
  }

  return (
    <View style={styles.screen}>
      <HeaderComponent
        rightButton="Pular"
        rightButtonAction={e => navigation.navigate('Root')}
      >
        <Text style={styles.headerDescription}>
          Selecione os aplicativos que você tem instalados no seu celular.
        </Text>
      </HeaderComponent>

      <BodyComponent roundedBottom>
        <View style={styles.rows}>
          {APPS.map(({ id, name, image }) => {
            return (
              <CardComponent
                key={id}
                id={id}
                name={name}
                startSelected={checkAlreadyAppsInstalled(id)}
                onStateChange={cardOnChange}
                image={image}
              />
            );
          })}
        </View>
      </BodyComponent>

      <FooterComponent>
        <Text style={styles.footerDescription}>
          Seu app não está na lista? Não se preocupe! Você poderá buscar mais
          tutoriais a seguir.
        </Text>

        <ButtonComponent
          text="Salvar"
          backgroundColor={colors.background}
          textColor={colors.primary}
          action={send}
          margin={0}
        />
      </FooterComponent>
    </View>
  );
}

const styles = StyleSheet.create({
  screen: {
    flex: 1,
    backgroundColor: colors.primary,
  },
  rows: {
    flexWrap: 'wrap',
    flexDirection: 'row',
    justifyContent: 'space-between',
  },
  header: {
    alignItems: 'center',
    justifyContent: 'center',
    color: colors.textWhite,
    fontSize: 30,
    fontWeight: 'bold',
  },
  headerDescription: {
    alignItems: 'center',
    textAlign: 'center',
    justifyContent: 'center',
    color: colors.textWhite,
    fontSize: 22,
  },
  footerDescription: {
    alignItems: 'center',
    textAlign: 'center',
    justifyContent: 'center',
    color: colors.textWhite,
    fontSize: 18,
    marginBottom: 20,
  },
});
